Struct assetmanager::accounts::CreateAssetManager
source · pub struct CreateAssetManager {
pub key: Pubkey,
pub asset_manager: Pubkey,
pub treasury: Pubkey,
pub authority: Pubkey,
pub payer: Pubkey,
pub system_program: Pubkey,
}Expand description
Generated client accounts for CreateAssetManager.
Fields
key: Pubkeyasset_manager: PubkeyThe asset manager state account.
treasury: PubkeyThe wallet holds the complete authority over the asset manager.
The wallet holds the complete authority over the asset manager.
payer: PubkeyThe wallet that pays for everything.
system_program: PubkeyThe system program.